<?php
/**
 * @package     Joomla.Plugin
 * @subpackage  Content.pagebreak
 *
 * @copyright   Copyright (C) 2005 - 2016 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

jimport('joomla.utilities.utility');

/**
 * Appointmind - Embed Schedule Plugin
 *
 * @since  1.6
 */
class PlgContentAppointmind extends JPlugin
{
    protected $mainToken = 'appointmind_calendar';
    
	/**
	 *
	 * @param   string   $context  The context of the content being passed to the plugin.
	 * @param   object   &$row     The article object.  Note $article->text is also available
	 * @param   mixed    &$params  The article params
	 * @param   integer  $page     The 'page' number
	 *
	 * @return  mixed  Always returns void or true
	 *
	 * @since   1.6
	 */
	public function onContentPrepare($context, &$article, &$params, $page = 0)
	{
		if ($context != 'com_content.article') {
		    return null;
		}
				
		if (strpos($article->text, '[appointmind_calendar') === false) {
		    return null;
		}
		
		$url = $this->params->get('url');
		
		if (empty($url)) {
		    return null;
		}

		$calendarId = '';
		if ($res = $this->_calendarId($article->text)) {
		    $calendarId = '?cap=' . $res;
		}
		
		$url .= $calendarId;
		
		$iframe = '
		    <iframe
                src="' . $url . '"
                id="calendarIframe"
                style="border:none;width:100%;height:1300px;padding:0;margin:0;"
                frameborder="0">
            </iframe>
	    ';
		
		$article->text = $this->_topArticlePart($article->text) . $iframe . $this->_bottomArticlePart($article->text);
		$article->text .= '<script type="text/javascript">iFrameResize({log:false, checkOrigin: false});</script>';
		
		$document = JFactory::getDocument();
		
		/**
		 * Will be included in the head section of the HTML page
		 */
		$document->addScript('//cdn.appointmind.net/templates/js/iframe-resizer/iframeResizer.min.js');
		
		/**
		 * Can't use this because it would be included in the head section of the HTML page
		 * but it must be placed below the iframe
		 */
		/*
		$document->addScriptDeclaration('iFrameResize({log:false, checkOrigin: false});');
		*/
		
		
		return true;
	}
	
	/**
	 * Get calendar ID from short code
	 * @param string $text
	 * @return string
	 */
	protected function _calendarId($text)
	{
	    $mainToken = '[' . $this->mainToken;
	    $idToken = 'id';
	    $text = strtolower($text);
	    $text = trim(substr($text, strpos($text, $mainToken) + strlen($mainToken), strlen($text)));
	    $text = substr($text, 0, strpos($text, ']'));
	    $text = trim(substr($text, strpos($text, $idToken) + strlen($idToken), strlen($text)));
	    $text = trim(substr($text, strpos($text, '=') + 1, strlen($text)));
	    $text = trim(substr($text, strpos($text, '"') + 1, strlen($text)));
	    $text = trim(substr($text, 0, strpos($text, '"')));
	    return $text;
	    
	}
	
	/**
	 * Get top part of the article text
	 * @param string $text
	 * @return string
	 */
	protected function _topArticlePart($text)
	{
	    $mainToken = '[' . $this->mainToken;
	    $text = trim(substr($text, 0, strpos($text, $mainToken)));
	    return $text;
	}
	
	/**
	 * Get bottom part of the article text
	 * @param string $text
	 * @return string
	 */
	protected function _bottomArticlePart($text)
	{
	    $mainToken = '[' . $this->mainToken;
	    $text = trim(substr($text, strpos($text, $mainToken) + strlen($mainToken), strlen($text)));
	    $text = trim(substr($text, strpos($text, ']') + 1, strlen($text)));
	    return $text;
	}
}
